==> rhoSimpleFlux-1.1.tar.gz: rhoSimpleFlux-1.1/setup.py <==
#!/usr/bin/env python

#--------------------------------------------------------------------------------------
## pythonFlu - Python wrapping for OpenFOAM C++ API
## Copyright (C) 2010- Alexey Petrov
## Copyright (C) 2009-2010 Pebble Bed Modular Reactor (Pty) Limited (PBMR)

## This program is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## See http://sourceforge.net/projects/pythonflu
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
from setuptools import setup, find_packages

setup( name = "rhoSimpleFlux",
       description = 'Python front-end of the rhoSimpleFoam',
       author = 'Alexey Petrov',
       author_email = 'alexey.petrov.nnov@gmail.com', 
       license = 'GPL',
       url = 'http://sourceforge.net/projects/pythonFlu',
       install_requires = [ 'Foam' ],
       platforms = [ 'linux' ],
       version = "1.1",
       classifiers = [ 'Development Status :: 3 - Alpha',
                       'Environment :: Console',
                       'Intended Audience :: Science/Research',
                       'License :: OSI Approved :: GNU General Public License (GPL)',
                       'Operating System :: POSIX',
                       'Programming Language :: Python',
                       'Topic :: Scientific/Engineering'],
       packages = find_packages(),
       entry_points = { 'console_scripts': [
           'rhoSimpleFlux = rhoSimpleFlux:entry_point'] },
       zip_safe = True )


#--------------------------------------------------------------------------------------

==> rhoSimpleFlux-1.2.tar.gz: rhoSimpleFlux-1.2/setup.py <==
#!/usr/bin/env python

#--------------------------------------------------------------------------------------
## pythonFlu - Python wrapping for OpenFOAM C++ API
## Copyright (C) 2010- Alexey Petrov
## Copyright (C) 2009-2010 Pebble Bed Modular Reactor (Pty) Limited (PBMR)

## This program is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## See http://sourceforge.net/projects/pythonflu
##
## Author : Alexey Petrov
##


#--------------------------------------------------------------------------------------
from setuptools import setup, find_packages

setup( name = "rhoSimpleFlux",
       description = 'Python front-end of the rhoSimpleFoam',
       author = 'Alexey Petrov',
       author_email = 'alexey.petrov.nnov@gmail.com', 
       license = 'GPL',
       url = 'http://sourceforge.net/projects/pythonFlu',
       install_requires = [ 'Foam >= 8.2-hybrid' ],
       platforms = [ 'linux' ],
       version = "1.2",
       classifiers = [ 'Development Status :: 3 - Alpha',
                       'Environment :: Console',
                       'Intended Audience :: Science/Research',
                       'License :: OSI Approved :: GNU General Public License (GPL)',
                       'Operating System :: POSIX',
                       'Programming Language :: Python',
                       'Topic :: Scientific/Engineering'],
       packages = find_packages(),
       entry_points = { 'console_scripts': [
           'rhoSimpleFlux = rhoSimpleFlux:entry_point'] },
       zip_safe = True )


#--------------------------------------------------------------------------------------
